# Project Obelisk

```whatnext
Something   something    star    gate
```

- [X] **secure desert burial site**
- [ ] research into runic meaning
- [/] carve runes into obelisk
- [ ] **bury obelisk in desert** @2026-01-05

    # Preparation
    - [ ] take star gate measurements @2025-06-01

## Discovery

~~~whatnext
Mess with Jackson
~~~

- [<] watch archaeologists discover (needs time machine) @1994-10-28
